==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federation/l10n/ja.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "信頼済サーバーとしてリストに登録済",
    "No server found with ID: %s" : "IDを持つサーバーが見つかりません： %s",
    "Could not remove server" : "サーバーを削除できませんでした",
    "Server is already in the list of trusted servers." : "信頼済サーバーとしてすでに登録されています。",
    "No server to federate with found" : "Nextcloud連携サーバーはありません。",
    "Could not add server" : "サーバーを追加できませんでした",
    "Trusted servers" : "信頼済サーバー",
    "Federation" : "連携",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "フェデレーションは、信頼できる他のサーバーと接続し、アカウントリストを交換することを可能にします。",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "フェデレーションでは他の信頼済サーバーとアカウントリストをやり取りすること許可します。例えば、フェデレーション共有時に他のサーバーのアカウントIDを自動補完します。",
    "External documentation for Federated Cloud Sharing" : "Federated Cloud Sharingの外部ドキュメント",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Nextcloud連携では、他の信頼できるサーバーと接続して、アカウントリストをやりとりすることができます。例えば、これにより他のサーバーのアカウントがフェデレーション共有の時に自動的に補完されます。フェデレーション共有を行うときには、信頼できるサーバーとして追加する必要はありません。",
    "Each server must validate the other. This process may require a few cron cycles." : "各サーバーは他のサーバーを検証しなければならない。このプロセスには数サイクルのcronが必要です。",
    "+ Add trusted server" : "+ 信頼済サーバーに追加",
    "Trusted server" : "信頼済サーバー",
    "Add" : "追加"
},
"nplurals=1; plural=0;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federation/l10n/ja.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "信頼済サーバーとしてリストに登録済",
    "No server found with ID: %s" : "IDを持つサーバーが見つかりません： %s",
    "Could not remove server" : "サーバーを削除できませんでした",
    "Server is already in the list of trusted servers." : "信頼済サーバーとしてすでに登録されています。",
    "No server to federate with found" : "Nextcloud連携サーバーはありません。",
    "Could not add server" : "サーバーを追加できませんでした",
    "Trusted servers" : "信頼済サーバー",
    "Federation" : "連携",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "フェデレーションは、信頼できる他のサーバーと接続し、アカウントリストを交換することを可能にします。",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "フェデレーションでは他の信頼済サーバーとアカウントリストをやり取りすること許可します。例えば、フェデレーション共有時に他のサーバーのアカウントIDを自動補完します。",
    "Could not add trusted server. Please try again later." : "信頼できるサーバーを追加できませんでした。もう一度試してください。",
    "Add trusted server" : "信頼できるサーバーを追加",
    "Server url" : "サーバーURL",
    "Add" : "追加",
    "Server ok" : "サーバーOK",
    "User list was exchanged at least once successfully with the remote server." : "ユーザーリストは少なくとも一度、リモートサーバーと正常に交換されました。",
    "Server pending" : "サーバー保留中",
    "Waiting for shared secret or initial user list exchange." : "共有シークレットまたは初期ユーザーリストの交換を待っています。",
    "Server access revoked" : "サーバーアクセスが取り消されました",
    "Server failure" : "サーバー障害",
    "Connection to the remote server failed or the remote server is misconfigured." : "リモートサーバーへの接続に失敗したか、リモートサーバーの設定に誤りがあります。",
    "Failed to delete trusted server. Please try again later." : "信頼済みサーバーの削除に失敗しました。もう一度試してください。",
    "Delete" : "削除",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Nextcloud連携では、他の信頼できるサーバーと接続して、アカウントリストをやりとりすることができます。例えば、これにより他のサーバーのアカウントがフェデレーション共有の時に自動的に補完されます。フェデレーション共有を行うときには、信頼できるサーバーとして追加する必要はありません。",
    "Each server must validate the other. This process may require a few cron cycles." : "各サーバーは他のサーバーを検証しなければならない。このプロセスには数サイクルのcronが必要です。",
    "External documentation for Federated Cloud Sharing" : "Federated Cloud Sharingの外部ドキュメント",
    "+ Add trusted server" : "+ 信頼済サーバーに追加",
    "Trusted server" : "信頼済サーバー"
},
"nplurals=1; plural=0;");
